@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 ###########################################################################
 #    OCRFeeder - The complete OCR suite
 #    Copyright (C) 2009 Joaquim Rocha
@@ -18,16 +16,16 @@
 #    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ###########################################################################
 
-from ocrfeeder.odf.draw import Frame, TextBox, Image
-from ocrfeeder.odf.opendocument import OpenDocumentText
-from ocrfeeder.odf.style import Style, MasterPage, GraphicProperties, ParagraphProperties, \
+from odf.draw import Frame, TextBox, Image
+from odf.opendocument import OpenDocumentText
+from odf.style import Style, MasterPage, GraphicProperties, ParagraphProperties, \
     TextProperties, PageLayout, PageLayoutProperties
-from ocrfeeder.odf.text import P, Page, PageSequence
+from odf.text import P, Page, PageSequence
 from ocrfeeder.util import TEXT_TYPE, IMAGE_TYPE, ALIGN_LEFT, ALIGN_RIGHT, ALIGN_CENTER, \
     ALIGN_FILL
 from ocrfeeder.util.configuration import ConfigurationManager
 from ocrfeeder.util.graphics import getImagePrintSize
-from ocrfeeder.util.lib import debug
+from ocrfeeder.util.log import debug
 from gi.repository import Pango
 from reportlab.pdfgen import canvas
 from reportlab.lib import units
@@ -51,7 +49,7 @@ class DocumentGeneratorManager(object):
         return self.GENERATORS.get(id)
 
     def getFormats(self):
-        return self.GENERATORS.keys()
+        return list(self.GENERATORS.keys())
 
 class DocumentGenerator(object):
 
@@ -174,7 +172,7 @@ class HtmlGenerator(DocumentGenerator):
 
     def save(self):
         pages = []
-        for i in xrange(len(self.bodies)):
+        for i in range(len(self.bodies)):
             previous_page = ''
             next_page = ''
             if i != 0:
@@ -216,7 +214,7 @@ class HtmlGenerator(DocumentGenerator):
             file.write(pages[0])
             file.close()
             if len(pages) > 1:
-                for i in xrange(1, len(pages)):
+                for i in range(1, len(pages)):
                     file = open(os.path.join(self.name, 'page%s.html' % (i + 1)), 'w')
                     file.write(pages[i])
                     file.close()
@@ -248,9 +246,9 @@ class OdtGenerator(DocumentGenerator):
         self.document.automaticstyles.addElement(frame_style_rotated)
 
     def addText(self, data_box):
-        text = data_box.getText().decode('utf-8')
+        text = data_box.getText()
         frame_style = Style(name='FrameStyle', family = 'graphic')
-        debug('Angle: ', data_box.text_data.angle)
+        debug('Angle: %s', data_box.text_data.angle)
         angle = data_box.text_data.angle
         if angle:
             frame_style = Style(name='FrameStyleRotated', family = 'graphic')
@@ -301,7 +299,7 @@ class OdtGenerator(DocumentGenerator):
             try:
                 os.unlink(image)
             except:
-                debug('Error removing image: %s' % image)
+                debug('Error removing image: %s', image)
 
     def __handlePageMaster(self, page_data):
         layout_name = 'Page%s%s' % (page_data.width, page_data.height)
@@ -368,7 +366,7 @@ class PlaintextGenerator(DocumentGenerator):
             # This will create a new file or **overwrite an existing file
             f = open(self.name, "w")
             try:
-                f.write(self.text.encode('utf-8'))
+                f.write(self.text)
             finally:
                 f.close() # Close the file
         except IOError:
